#
# spec file for package zeromq
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           zeromq
Version:        3.2.4
Release:        8.1
Url:            http://www.zeromq.org/
Summary:        Lightweight messaging kernel
License:        LGPL-3.0+
Group:          Productivity/Networking/Web/Servers
Source:         http://download.zeromq.org/%{name}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%ifarch %ix86 x86_64
 %if 0%{?suse_version} >= 1100
  %define with_pgm 1
 %endif
%endif
BuildRequires:  gcc-c++
%if 0%{?suse_version} && 0%{?suse_version} < 1100
BuildRequires:  e2fsprogs-devel
%else
%if 0%{?rhel} >= 6 || 0%{?centos_version} >= 6
BuildRequires:  e2fsprogs-devel
BuildRequires:  libuuid-devel
%else
%if 0%{?fedora_verison} || 0%{?centos_version} == 5
BuildRequires:  e2fsprogs-devel
%else
%if 0%{?mdkversion} && 0%{?mdkversion} < 201000
BuildRequires:  e2fsprogs-devel
%else
BuildRequires:  libuuid-devel
%endif
%endif
%endif
%endif
%if 0%{?with_pgm}
BuildRequires:  pkgconfig
BuildRequires:  python
%if 0%{?suse_version} && 0%{?suse_version} < 1130
BuildRequires:  glib2 >= 2.8
%else
BuildRequires:  pkgconfig(glib-2.0) >= 2.8
%endif
%endif

%description
The 0MQ lightweight messaging kernel is a library which extends the
standard socket interfaces with features traditionally provided by
specialised messaging middleware products. 0MQ sockets provide an
abstraction of asynchronous message queues, multiple messaging patterns,
message filtering (subscriptions), seamless access to multiple transport
protocols and more.

%define lib_name libzmq3

%package -n %{lib_name}
Summary:        Shared Library for ZeroMQ
Group:          Productivity/Networking/Web/Servers

%description -n %{lib_name}
The 0MQ lightweight messaging kernel is a library which extends the
standard socket interfaces with features traditionally provided by
specialised messaging middleware products. 0MQ sockets provide an
abstraction of asynchronous message queues, multiple messaging patterns,
message filtering (subscriptions), seamless access to multiple transport
protocols and more.

This package holds the shared library part of the ZeroMQ package.

%package devel
Summary:        Development files for ZeroMQ
Group:          Development/Languages/C and C++
Requires:       %{lib_name} = %{version}
Provides:       libzmq-devel = %{version}

%description devel
The 0MQ lightweight messaging kernel is a library which extends the
standard socket interfaces with features traditionally provided by
specialised messaging middleware products. 0MQ sockets provide an
abstraction of asynchronous message queues, multiple messaging patterns,
message filtering (subscriptions), seamless access to multiple transport
protocols and more.

This package holds the development files for ZeroMQ.

%prep
%setup -q

%build
%if 0%{?with_pgm} && 0%{?sles_version} == 9
export PKG_CONFIG_PATH="/opt/gnome/%{_lib}/pkgconfig:$PKG_CONFIG_PATH"
%endif
%configure \
%if 0%{?with_pgm}
  --with-pgm \
%endif
  --disable-static \
  --with-pic
make %{?_smp_mflags} V=1

%install
%makeinstall V=1
find %{buildroot} -name "*.la" -delete

%post   -n %{lib_name} -p /sbin/ldconfig

%postun -n %{lib_name} -p /sbin/ldconfig

%files -n %{lib_name}
%defattr(-,root,root,-)
%doc AUTHORS ChangeLog COPYING COPYING.LESSER NEWS README
%{_libdir}/libzmq.so.*

%files devel
%defattr(-,root,root,-)
%{_includedir}/zmq*
%{_libdir}/libzmq.so
%{_libdir}/pkgconfig/libzmq.pc
%{_mandir}/man3/zmq*.3*
%{_mandir}/man7/zmq*.7*

%changelog
* Sat Sep 21 2013 p.drouand@gmail.com
- Update to version 3.2.4
  For details see /usr/share/doc/packages/libzmq3/NEWS
* Fri Nov 23 2012 mrueckert@suse.de
- Update to version 3.2.2
  For details see /usr/share/doc/packages/libzmq3/NEWS
* Sat Jan 28 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
* Wed Sep 28 2011 saschpe@gmx.de
- Fixed license to LGPL-3.0+ (SPDX style)
* Wed Aug 24 2011 mrueckert@suse.de
- make sure the compiler commandlines are shown (V=1)
- make it build on sle11 again. we dont have pkg-config provides
  there
* Fri Aug 19 2011 saschpe@suse.de
- Use %%makeinstall marcro instead of %%make_install to fix build
  on Mandriva and Fedora
* Fri Aug 19 2011 saschpe@suse.de
- Add libuuid-devel to RedHat BuildRequires to fix build
* Fri Aug 19 2011 saschpe@suse.de
- Update to version 2.1.7:
  * Fixed issue 188, assert when closing socket that had unread multipart
    data still on it (affected PULL, SUB, ROUTER, and DEALER sockets).
  * Fixed issue 191, message atomicity issue with PUB sockets (an old issue).
  * Fixed issue 199 (affected ROUTER/XREP sockets, an old issue).
  * Fixed issue 206, assertion failure in zmq.cpp:223, affected all sockets
    (bug was introduced in 2.1.6 as part of message validity checking).
  * Fixed issue 211, REP socket asserted if sent malformed envelope (old issue
    due to abuse of assertions for error checking).
  * Fixed issue 212, reconnect failing after resume from sleep on Windows
    (due to not handling WSAENETDOWN).
  * Properly handle WSAENETUNREACH on Windows (e.g. if client connects
    before server binds).
  * Fixed memory leak with threads on Windows.
- Changes from previous releases:
  * See https://raw.github.com/zeromq/zeromq2-1/master/NEWS
- Run spec-cleaner, added proper spec license header, shorter file lists
- Split out documentation package
* Wed Dec  1 2010 mrueckert@suse.de
- update to version 2.0.10
  * Upgrade OpenPGM to 2.1.28~dfsg (Martin Lucina)
  * Added a ZMQ_VERSION macro to zmq.h for compile-time API version
    detection (Martin Sustrik, Gonzalo Diethelm, Martin Lucina)
  * Fix memory leak under Windows (Taras Shpot)
  * Makefile.am: Add missing files to distribution, improve
    maintainer-clean (Martin Lucina)
  * Add support for RHEL6 in the spec file (Sebastian Otaegui)
  * configure.in: Do not patch libtool rpath handling (Martin Lucina)
  * Fixing the Red Hat packaging (Martin Sustrik)
  * zmq_msg_move called on uninitialised message in xrep_t::xrecv
  - - fixed (Max Wolf)
  * crash when closing an ypipe -- fixed (Dhammika Pathirana)
  * REQ socket can die when reply is delivered on wrong unerlying
    connection -- fixed (Martin Sustrik)
  * if TSC jumps backwards (in case of migration to a
    different CPU core) latency peak may occur -- fixed
    (Martin Sustrik)
  * values of RATE, RECOVERY_IVL and SWAP options are checked for
    negative values (Martin Sustrik)
- added provides for libzmq-devel
* Mon Sep  6 2010 mrueckert@suse.de
- initial package
